==> haskell-hspec-megaparsec-2.2.1-107.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-megaparsec
version:              2.2.1
visibility:           public
id:                   hspec-megaparsec-2.2.1-DpLoHb8GzOyJnJAxawhrTb
key:                  hspec-megaparsec-2.2.1-DpLoHb8GzOyJnJAxawhrTb
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/hspec-megaparsec
synopsis:             Utility functions for testing Megaparsec parsers with Hspec
description:
    Utility functions for testing Megaparsec parsers with Hspec.

category:             Testing, Parsing
abi:                  174874016e6ffe7c349782a2838e9820
exposed:              True
exposed-modules:      Test.Hspec.Megaparsec
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-megaparsec-2.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-megaparsec-2.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-megaparsec-2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-megaparsec
hs-libraries:         HShspec-megaparsec-2.2.1-DpLoHb8GzOyJnJAxawhrTb
depends:
    base-4.18.2.1 hspec-expectations-0.8.4-7xRGbz7YGlh8mVR0kjpKwh
    megaparsec-9.7.0-Fzm61TdpQu7Cpey7aoa8J9

haddock-interfaces:
    /usr/share/doc/haskell-hspec-megaparsec/html/hspec-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-hspec-megaparsec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-megaparsec-2.2.1-108-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-megaparsec
version:              2.2.1
visibility:           public
id:                   hspec-megaparsec-2.2.1-9tA55aqIYMmFwGVojtbS37
key:                  hspec-megaparsec-2.2.1-9tA55aqIYMmFwGVojtbS37
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/hspec-megaparsec
synopsis:             Utility functions for testing Megaparsec parsers with Hspec
description:
    Utility functions for testing Megaparsec parsers with Hspec.

category:             Testing, Parsing
abi:                  f6d45ece3048683d9da1d6f57184734c
exposed:              True
exposed-modules:      Test.Hspec.Megaparsec
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-megaparsec-2.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-megaparsec-2.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-megaparsec-2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-megaparsec
hs-libraries:         HShspec-megaparsec-2.2.1-9tA55aqIYMmFwGVojtbS37
depends:
    base-4.18.2.1 hspec-expectations-0.8.4-JRz47SURfXgGxfIuVeuxEa
    megaparsec-9.7.0-CJUMznUvVaqA9LkZfHNyDE

haddock-interfaces:
    /usr/share/doc/haskell-hspec-megaparsec/html/hspec-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-hspec-megaparsec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
